@@ -12,7 +12,8 @@ from cmdstanpy.cmdstan_args import (
 )
 from cmdstanpy.utils import check_sampler_csv, get_logger, scan_config
 
-from .mcmc import CmdStanGQ, CmdStanMCMC
+from .gq import CmdStanGQ
+from .mcmc import CmdStanMCMC
 from .metadata import InferenceMetadata
 from .mle import CmdStanMLE
 from .runset import RunSet
@@ -216,5 +217,5 @@ def from_csv(
             return None
     except (IOError, OSError, PermissionError) as e:
         raise ValueError(
-            'An error occured processing the CSV files:\n\t{}'.format(str(e))
+            'An error occurred processing the CSV files:\n\t{}'.format(str(e))
         ) from e
