@@ -84,6 +84,11 @@ class GenerateQuantitiesTest(CustomTestCase):
             + bern_gqs.draws_pd().shape[1],
         )
 
+        self.assertEqual(
+            list(bern_gqs.draws_pd(vars=['y_rep']).columns),
+            column_names,
+        )
+
     def test_from_csv_files_bad(self):
         # gq model
         stan = os.path.join(DATAFILES_PATH, 'bernoulli_ppc.stan')
@@ -349,7 +354,7 @@ class GenerateQuantitiesTest(CustomTestCase):
             self.assertEqual(y_rep[0, i], bern_data['y'][i])
 
     def test_no_xarray(self):
-        with self.without_import('xarray', cmdstanpy.stanfit.mcmc):
+        with self.without_import('xarray', cmdstanpy.stanfit.gq):
             with self.assertRaises(ImportError):
                 # if this fails the testing framework is the problem
                 import xarray as _  # noqa
