@@ -7,6 +7,7 @@ import shutil
 import unittest
 from math import fabs
 
+import numpy as np
 from testfixtures import LogCapture
 
 from cmdstanpy.cmdstan_args import CmdStanArgs, VariationalArgs
@@ -37,10 +38,8 @@ class CmdStanVBTest(unittest.TestCase):
             os.path.join(DATAFILES_PATH, 'variational', 'eta_big_output.csv')
         ]
         variational = CmdStanVB(runset)
-        self.assertIn(
-            'CmdStanVB: model=eta_should_be_big', variational.__repr__()
-        )
-        self.assertIn('method=variational', variational.__repr__())
+        self.assertIn('CmdStanVB: model=eta_should_be_big', repr(variational))
+        self.assertIn('method=variational', repr(variational))
         self.assertEqual(
             variational.column_names,
             ('lp__', 'log_p__', 'log_g__', 'mu[1]', 'mu[2]'),
@@ -58,10 +57,8 @@ class CmdStanVBTest(unittest.TestCase):
     def test_instantiate_from_csvfiles(self):
         csvfiles_path = os.path.join(DATAFILES_PATH, 'variational')
         variational = from_csv(path=csvfiles_path)
-        self.assertIn(
-            'CmdStanVB: model=eta_should_be_big', variational.__repr__()
-        )
-        self.assertIn('method=variational', variational.__repr__())
+        self.assertIn('CmdStanVB: model=eta_should_be_big', repr(variational))
+        self.assertIn('method=variational', repr(variational))
         self.assertEqual(
             variational.column_names,
             ('lp__', 'log_p__', 'log_g__', 'mu[1]', 'mu[2]'),
@@ -88,7 +85,7 @@ class CmdStanVBTest(unittest.TestCase):
             ('lp__', 'log_p__', 'log_g__', 'mu[1]', 'mu[2]'),
         )
         self.assertEqual(1, len(variational.metadata.stan_vars_dims))
-        self.assertTrue('mu' in variational.metadata.stan_vars_dims)
+        self.assertIn('mu', variational.metadata.stan_vars_dims)
         self.assertEqual(variational.metadata.stan_vars_dims['mu'], (2,))
         mu = variational.stan_variable(var='mu')
         self.assertEqual(mu.shape, (2,))
@@ -108,7 +105,7 @@ class CmdStanVBTest(unittest.TestCase):
             algorithm='meanfield',
         )
         self.assertEqual(3, len(multidim_variational.metadata.stan_vars_dims))
-        self.assertTrue('y_rep' in multidim_variational.metadata.stan_vars_dims)
+        self.assertIn('y_rep', multidim_variational.metadata.stan_vars_dims)
         self.assertEqual(
             multidim_variational.metadata.stan_vars_dims['y_rep'], (5, 4, 3)
         )
@@ -122,11 +119,11 @@ class CmdStanVBTest(unittest.TestCase):
         self.assertEqual(
             len(vars), len(multidim_variational.metadata.stan_vars_dims)
         )
-        self.assertTrue('y_rep' in vars)
+        self.assertIn('y_rep', vars)
         self.assertEqual(vars['y_rep'].shape, (5, 4, 3))
-        self.assertTrue('beta' in vars)
+        self.assertIn('beta', vars)
         self.assertEqual(vars['beta'].shape, (2,))
-        self.assertTrue('frac_60' in vars)
+        self.assertIn('frac_60', vars)
         self.assertTrue(isinstance(vars['frac_60'], float))
 
 
@@ -231,7 +228,7 @@ class VariationalTest(unittest.TestCase):
                 seed=12345,
             )
         console = sys_stdout.getvalue()
-        self.assertTrue('Chain [1] method = variational' in console)
+        self.assertIn('Chain [1] method = variational', console)
 
     def test_exe_only(self):
         stan = os.path.join(DATAFILES_PATH, 'bernoulli.stan')
@@ -264,6 +261,29 @@ class VariationalTest(unittest.TestCase):
         # make sure the name 'imag' isn't magic
         self.assertEqual(fit.stan_variable('imag').shape, (2,))
 
+    def test_attrs(self):
+        stan = os.path.join(DATAFILES_PATH, 'named_output.stan')
+        model = CmdStanModel(stan_file=stan)
+        jdata = os.path.join(DATAFILES_PATH, 'bernoulli.data.json')
+        fit = model.variational(
+            data=jdata,
+            require_converged=False,
+            seed=12345,
+            algorithm='meanfield',
+        )
+
+        self.assertEqual(fit.a, 4.5)
+        self.assertEqual(fit.b.shape, (3,))
+        self.assertIsInstance(fit.theta, float)
+
+        self.assertEqual(fit.stan_variable('thin'), 3.5)
+
+        self.assertIsInstance(fit.variational_params_np, np.ndarray)
+        self.assertEqual(fit.stan_variable('variational_params_np'), 0)
+
+        with self.assertRaisesRegex(AttributeError, 'Unknown variable name:'):
+            dummy = fit.c
+
 
 if __name__ == '__main__':
     unittest.main()
